diff --git a/samples/nrf9160/https_client/src/main.c b/samples/nrf9160/https_client/src/main.c
index 1371c7d6..51326f7c 100644
--- a/samples/nrf9160/https_client/src/main.c
+++ b/samples/nrf9160/https_client/src/main.c
@@ -39,6 +39,19 @@ static const char cert[] = {
 
 BUILD_ASSERT(sizeof(cert) < KB(4), "Certificate too large");
 
+static void at_handler(void *context, const char *response)
+{
+	if (response == NULL) {
+		printk("Response buffer is NULL-pointer");
+		return;
+	}
+	const char * cgev_notification_filter = "+CGEV:";
+	if (strncmp(cgev_notification_filter, response, strlen(cgev_notification_filter)) == 0) {
+		printk("Match for +CGEV notification\n");
+		printk("Received notification %s\n", response);
+	}
+
+}
 
 /* Initialize AT communications */
 int at_comms_init(void)
@@ -56,7 +69,16 @@ int at_comms_init(void)
 		printk("Failed to initialize AT notifications, err %d\n", err);
 		return err;
 	}
-
+	err = at_notif_register_handler(NULL, at_handler);
+	if (err) {
+		printk("Failed to initialize AT nofitication handler, err %d\n", err);
+		return err;
+	}
+	err = at_cmd_write("AT+CGEREP=1", NULL, 0, NULL);
+	if (err) {
+		printk("Unable to send AT command, err %d\n", err);
+		return err;
+	}
 	return 0;
 }
 
